==> anglemania_0.99.6.tar.gz: anglemania/tests/testthat/_snaps/anglemania.md <==
# anglemania works correctly with method cosine

    Code
      metadata(sce)$anglemania$list_stats$mean_zscore[1:10, 1:10]
    Output
                   [,1]       [,2]       [,3]        [,4]        [,5]       [,6]
       [1,]  0.00000000 -1.4773877 -0.6690115  0.80957395  0.21191114  0.3065459
       [2,] -1.43297508  0.0000000  0.8094372  1.79591873  0.87491750  0.0903189
       [3,] -0.70975605  0.8090174  0.0000000 -0.90002758 -0.14215190  0.4217798
       [4,]  0.81025807  1.7916458 -0.8103351  0.00000000 -0.29386285 -0.2877692
       [5,]  0.26228504  0.8796571 -0.2190412 -0.31429554  0.00000000 -0.7944232
       [6,]  0.34210706  0.1727196  0.4235970 -0.32724467 -0.79625202  0.0000000
       [7,]  0.60813294  0.4576137 -1.4403958 -0.03807431  0.35694728  0.5394522
       [8,] -0.03868058 -1.0958225 -0.7680151 -0.62207485 -1.42724690 -0.8197054
       [9,]  1.26715940  0.3486664 -0.5030029 -0.76152650 -0.66668260 -0.4825756
      [10,]  0.49115807  1.1467226  0.7976727 -0.27013900  0.03028304  0.8112288
                   [,7]        [,8]       [,9]       [,10]
       [1,]  0.56547617 -0.03856716  1.3244559  0.55175817
       [2,]  0.42066942 -1.07809086  0.3689397  1.22820514
       [3,] -1.43454207 -0.81612340 -0.5660148  0.85049090
       [4,] -0.03013217 -0.60874763 -0.7697346 -0.26408713
       [5,]  0.33947128 -1.41539357 -0.7042153  0.09207322
       [6,]  0.58879355 -0.90169837 -0.4733153  0.95262076
       [7,]  0.00000000 -0.04890247 -1.3990884  0.13388386
       [8,] -0.06086220  0.00000000  0.2264090 -0.38716311
       [9,] -1.28262315  0.21655711  0.0000000  0.29156726
      [10,]  0.09079824 -0.37769685  0.2645134  0.00000000

---

    Code
      metadata(sce)$anglemania$list_stats$sn_zscore[1:10, 1:10]
    Output
                 [,1]       [,2]      [,3]      [,4]        [,5]      [,6]       [,7]
       [1,]        NA 3.87928890 3.7213414 1.5550667  0.23116551 1.1093569 0.43675655
       [2,] 3.3234406         NA 2.6894229 1.7746389  1.81948152 0.0475004 0.61626266
       [3,] 3.3486305 2.12554305        NA 0.5347330  0.07006687 0.6157208 3.20481223
       [4,] 1.7557127 1.90940919 0.5017815        NA  2.67420836 0.7127632 0.35230911
       [5,] 0.2814584 2.06177351 0.1102260 2.7147101          NA 1.0660911 4.96375673
       [6,] 1.2925884 0.08738832 0.6689559 0.6989744  1.12999842        NA 0.46300567
       [7,] 0.4210103 0.57464016 3.6559091 0.6177018 20.23533063 0.4351825         NA
       [8,] 0.1972052 2.70836022 1.0290168 1.1901274  1.60093202 0.7769169 0.03782587
       [9,] 1.1991785 0.85301337 2.6746701 1.1487110  1.87190277 0.9452842 1.29334315
      [10,] 0.8240564 0.54672981 0.7297777 0.2970755  0.04424840 2.7762187 1.14792773
                  [,8]      [,9]     [,10]
       [1,] 0.18233120 1.2293105 0.9397228
       [2,] 2.42966432 0.9163600 0.5676517
       [3,] 1.03317093 2.7531425 0.7122352
       [4,] 1.21548319 1.1192943 0.2652472
       [5,] 1.80999042 1.7224239 0.1147065
       [6,] 0.73115522 0.9906576 2.2279278
       [7,] 0.02922472 1.2437533 1.6213504
       [8,]         NA 0.3670766 1.0166472
       [9,] 0.34913215        NA 0.7517291
      [10,] 1.22489605 0.7668660        NA

---

    Code
      get_anglemania_genes(sce)
    Output
       [1] "gene43"  "gene207" "gene119" "gene130" "gene25"  "gene209" "gene69" 
       [8] "gene184" "gene63"  "gene71"  "gene172" "gene40"  "gene105" "gene88" 
      [15] "gene159" "gene14"  "gene155" "gene66"  "gene122" "gene157" "gene193"
      [22] "gene58"  "gene240" "gene150" "gene286"

==> anglemania_1.0.0.tar.gz: anglemania/tests/testthat/_snaps/anglemania.md <==
# anglemania works correctly with method cosine

    Code
      metadata(sce)$anglemania$list_stats$mean_zscore[1:10, 1:10]
    Output
                   [,1]       [,2]       [,3]        [,4]        [,5]       [,6]
       [1,]  0.00000000 -1.4773877 -0.6690115  0.80957395  0.21191114  0.3065459
       [2,] -1.43297508  0.0000000  0.8094372  1.79591873  0.87491750  0.0903189
       [3,] -0.70975605  0.8090174  0.0000000 -0.90002758 -0.14215190  0.4217798
       [4,]  0.81025807  1.7916458 -0.8103351  0.00000000 -0.29386285 -0.2877692
       [5,]  0.26228504  0.8796571 -0.2190412 -0.31429554  0.00000000 -0.7944232
       [6,]  0.34210706  0.1727196  0.4235970 -0.32724467 -0.79625202  0.0000000
       [7,]  0.60813294  0.4576137 -1.4403958 -0.03807431  0.35694728  0.5394522
       [8,] -0.03868058 -1.0958225 -0.7680151 -0.62207485 -1.42724690 -0.8197054
       [9,]  1.26715940  0.3486664 -0.5030029 -0.76152650 -0.66668260 -0.4825756
      [10,]  0.49115807  1.1467226  0.7976727 -0.27013900  0.03028304  0.8112288
                   [,7]        [,8]       [,9]       [,10]
       [1,]  0.56547617 -0.03856716  1.3244559  0.55175817
       [2,]  0.42066942 -1.07809086  0.3689397  1.22820514
       [3,] -1.43454207 -0.81612340 -0.5660148  0.85049090
       [4,] -0.03013217 -0.60874763 -0.7697346 -0.26408713
       [5,]  0.33947128 -1.41539357 -0.7042153  0.09207322
       [6,]  0.58879355 -0.90169837 -0.4733153  0.95262076
       [7,]  0.00000000 -0.04890247 -1.3990884  0.13388386
       [8,] -0.06086220  0.00000000  0.2264090 -0.38716311
       [9,] -1.28262315  0.21655711  0.0000000  0.29156726
      [10,]  0.09079824 -0.37769685  0.2645134  0.00000000

---

    Code
      metadata(sce)$anglemania$list_stats$sn_zscore[1:10, 1:10]
    Output
                 [,1]       [,2]      [,3]      [,4]        [,5]      [,6]       [,7]
       [1,]        NA 3.87928890 3.7213414 1.5550667  0.23116551 1.1093569 0.43675655
       [2,] 3.3234406         NA 2.6894229 1.7746389  1.81948152 0.0475004 0.61626266
       [3,] 3.3486305 2.12554305        NA 0.5347330  0.07006687 0.6157208 3.20481223
       [4,] 1.7557127 1.90940919 0.5017815        NA  2.67420836 0.7127632 0.35230911
       [5,] 0.2814584 2.06177351 0.1102260 2.7147101          NA 1.0660911 4.96375673
       [6,] 1.2925884 0.08738832 0.6689559 0.6989744  1.12999842        NA 0.46300567
       [7,] 0.4210103 0.57464016 3.6559091 0.6177018 20.23533063 0.4351825         NA
       [8,] 0.1972052 2.70836022 1.0290168 1.1901274  1.60093202 0.7769169 0.03782587
       [9,] 1.1991785 0.85301337 2.6746701 1.1487110  1.87190277 0.9452842 1.29334315
      [10,] 0.8240564 0.54672981 0.7297777 0.2970755  0.04424840 2.7762187 1.14792773
                  [,8]      [,9]     [,10]
       [1,] 0.18233120 1.2293105 0.9397228
       [2,] 2.42966432 0.9163600 0.5676517
       [3,] 1.03317093 2.7531425 0.7122352
       [4,] 1.21548319 1.1192943 0.2652472
       [5,] 1.80999042 1.7224239 0.1147065
       [6,] 0.73115522 0.9906576 2.2279278
       [7,] 0.02922472 1.2437533 1.6213504
       [8,]         NA 0.3670766 1.0166472
       [9,] 0.34913215        NA 0.7517291
      [10,] 1.22489605 0.7668660        NA

---

    Code
      get_anglemania_genes(sce)
    Output
       [1] "gene270" "gene294" "gene66"  "gene122" "gene18"  "gene161" "gene26" 
       [8] "gene276" "gene15"  "gene111" "gene74"  "gene280" "gene150" "gene286"
      [15] "gene31"  "gene251" "gene85"  "gene200" "gene6"   "gene184"
